﻿using System;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;

namespace HeuristicLab.HiveEngine.Views {
  [View("Hive Engine View")]
  [Content(typeof(HiveEngine), IsDefaultView = true)]
  public sealed partial class HiveEngineView : ItemView {
    public new HiveEngine Content {
      get { return (HiveEngine)base.Content; }
      set { base.Content = value; }
    }

    public HiveEngineView() {
      InitializeComponent();
    }

    protected override void DeregisterContentEvents() {
      Content.ExecutionStateChanged -= new EventHandler(Content_ExecutionStateChanged);
      Content.ExecutionTimeOnHiveChanged -= new EventHandler(Content_ExecutionTimeOnHiveChanged);
      base.DeregisterContentEvents();
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.ExecutionStateChanged += new EventHandler(Content_ExecutionStateChanged);
      Content.ExecutionTimeOnHiveChanged += new EventHandler(Content_ExecutionTimeOnHiveChanged);
    }

    #region Event Handlers (Content)
    private void Content_ExecutionStateChanged(object sender, EventArgs e) {
      if (InvokeRequired) {
        Invoke(new EventHandler(Content_ExecutionStateChanged), sender, e);
      } else {
        executionTimeTextBox.Text = Content.ExecutionTime.ToString();
      }
    }

    private void Content_ExecutionTimeOnHiveChanged(object sender, EventArgs e) {
      if (InvokeRequired) {
        Invoke(new EventHandler(Content_ExecutionTimeOnHiveChanged), sender, e);
      } else {
        executionTimeOnHiveTextBox.Text = Content.ExecutionTimeOnHive.ToString();
      }
    }
    #endregion

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        resourceIdsTextBox.Text = string.Empty;
        priorityTextBox.Text = string.Empty;
        executionTimeOnHiveTextBox.Text = string.Empty;
        useLocalPluginsCheckBox.Checked = false;
        hiveExperimentListView.Content = null;
        logView.Content = null;
      } else {
        resourceIdsTextBox.Text = Content.ResourceNames;
        priorityTextBox.Text = Content.Priority.ToString();
        executionTimeOnHiveTextBox.Text = Content.ExecutionTimeOnHive.ToString();
        useLocalPluginsCheckBox.Checked = Content.UseLocalPlugins;
        hiveExperimentListView.Content = Content.HiveExperiments;
        logView.Content = Content.Log;
      }
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      // Enable or disable controls based on whether the content is null or the view is set readonly
      if (Content != null) {
        resourceIdsTextBox.ReadOnly = this.ReadOnly;
        priorityTextBox.ReadOnly = this.ReadOnly;
        useLocalPluginsCheckBox.Enabled = !this.ReadOnly;
      } else {
        resourceIdsTextBox.ReadOnly = false;
        priorityTextBox.ReadOnly = false;
        useLocalPluginsCheckBox.Enabled = false;
      }
    }
    
    #region Event Handlers (child controls)
    private void resourceIdsTextBox_TextChanged(object sender, EventArgs e) {
      Content.ResourceNames = resourceIdsTextBox.Text;
    }

    private void priorityTextBox_TextChanged(object sender, EventArgs e) {
      Content.Priority = int.Parse(priorityTextBox.Text);
    }

    private void useLocalPluginsCheckBox_CheckedChanged(object sender, EventArgs e) {
      Content.UseLocalPlugins = useLocalPluginsCheckBox.Checked;
    }
    #endregion


  }
}
